==> yylivesdk4cloud-audiovideo-1.8.15-sources.jar: com/yy/yylivesdk4cloud/ThunderConstant.java <==
package com.yy.yylivesdk4cloud;

/**
 * Created by xiongxiong on 2017/10/30.
 */

public final class ThunderConstant {

	public static final class ThunderAreaType {
		/**
		 * 默认值(国内)
		 */
		public static final int THUNDERAREA_DEFAULT = 0;
		/**
		 * 俄罗斯
		 */
		public static final int THUNDERAREA_RUSSIA = 1;
		/**
		 * 马来西亚
		 */
		public static final int THUNDERAREA_MALAYSIA = 2;
		/**
		 * 国外
		 */
		public static final int THUNDERAREA_FOREIGN = 100;
		/**
		 * yy-reserved
		 */
		public static final int THUNDERAREA_RESERVED = 101;
	}

	public static final class ThunderUserRole {
		/**
		 * 纯观众
		 */
		public static final int THUNDERUSER_ROLE_AUDIENCE = 0;
		/**
		 * 主播，如果观众跟主播连麦后则自己也成为了主播
		 */
		public static final int THUNDERUSER_ROLE_ANCHOR = 1;
	}

	public static final class ThunderLogLevel {
		public static final int THUNDERLOG_LEVEL_TRACE = 0;
		public static final int THUNDERLOG_LEVEL_DEBUG = 1;
		public static final int THUNDERLOG_LEVEL_INFO = 2;
		public static final int THUNDERLOG_LEVEL_WARN = 3;
		public static final int THUNDERLOG_LEVEL_ERROR = 4;
		public static final int THUNDERLOG_LEVEL_RELEASE = 10;
	}

	public static final class ThunderCameraPosition {
		public static final int THUNDERCAMERA_POSITION_FRONT = 0;
		public static final int THUNDERCAMERA_POSITION_BACK = 1;
	}

	public static final class ThunderPublishOrientation {
		public static final int THUNDERPUBLISH_VIDEO_ORIENTATION_PORTRAIT = 0;
		public static final int THUNDERPUBLISH_VIDEO_ORIENTATION_LANDSCAPE = 1;
	}

	public static final class ThunderVideoEncodeType {
		public static final int THUNDER_ENCODE_TYPE_H264 = 1;
		public static final int THUNDERVIDEO_ENCODE_TYPE_H265 = 2;
	}

	public static final class ThunderVideoViewScaleMode {
		public static final int THUNDERVIDEOVIEW_SCALE_MODE_FILL = 0;
		public static final int THUNDERVIDEOVIEW_SCALE_MODE_ASPECT_FIT = 1;
		public static final int THUNDERVIDEOVIEW_SCALE_MODE_CLIP_TO_BOUNDS = 2;
	}

	/*! 使用 ThunderVideoLevel代替*/
	@Deprecated
	public static final class ThunderStreamLevelType {
		public static final int THUNDERSTREAM_LEVEL_360P = 1;
		public static final int THUNDERSTREAM_LEVEL_540P = 2;
		public static final int THUNDERSTREAM_LEVEL_720P = 3;
		public static final int THUNDERSTREAM_LEVEL_720P60S = 4;
		public static final int THUNDERSTREAM_LEVEL_1080P = 5;
	}

	public static final class ThunderSoundEffectMode {
		public static final int THUNDERSOUND_EFFECT_MODE_NONE = 0; //关闭模式
		public static final int THUNDERSOUND_EFFECT_MODE_VALLEY = 1; //VALLEY模式
		public static final int THUNDERSOUND_EFFECT_MODE_RANDB = 2; //R&B模式
		public static final int THUNDERSOUND_EFFECT_MODE_KTV = 3; //KTV模式
		public static final int THUNDERSOUND_EFFECT_MODE_CHARMING = 4; // CHARMING模式
	}


	public static final class ThunderVideoLevel {
		public static final int THUNDERVIDEO_LEVEL_NORMAL = 1; /*! 普通 */
		public static final int THUNDERVIDEO_LEVEL_HIGHQULITY = 2; /*! 高清 */
		public static final int THUNDERVIDEO_LEVEL_SUPERQULITY = 3; /*! 超清 */
		public static final int THUNDERVIDEO_LEVEL_BLUERAY_2M = 4; /*! 蓝光 2M */
		public static final int THUNDERVIDEO_LEVEL_BLUERAY_4M = 5; /*! 蓝光 4M */
		public static final int THUNDERVIDEO_LEVEL_BLUERAY_6M = 6; /*! 蓝光 6M */
		public static final int THUNDERVIDEO_LEVEL_BLUERAY_8M = 7; /*! 蓝光 8M */
	}

	public static final class ThunderPublishPlayType {
		public static final int THUNDERPUBLISH_PLAY_SINGLE = 0;  // 单人开播
		public static final int THUNDERPUBLISH_PLAY_INTERACT = 1;  // 视频连麦开播
		public static final int THUNDERPUBLISH_PLAY_SCREENCAP = 2;  // 录屏开播
	}

	public static final class ThunderPublishVideoMode {
		public static final int THUNDERPUBLISH_VIDEO_MODE_DEFAULT = -1;        /*! 未定义，由配置自由决定开播清晰度*/
		public static final int THUNDERPUBLISH_VIDEO_MODE_NORMAL = 1;          /*! 普通 */
		public static final int THUNDERPUBLISH_VIDEO_MODE_HIGHQULITY = 2;      /*! 高清 */
		public static final int THUNDERPUBLISH_VIDEO_MODE_SUPERQULITY = 3;     /*! 超清 */
		public static final int THUNDERPUBLISH_VIDEO_MODE_BLUERAY_2M = 4;      /*! 蓝光 2M */
		public static final int THUNDERPUBLISH_VIDEO_MODE_BLUERAY_4M = 5;      /*! 蓝光 4M */
		public static final int THUNDERPUBLISH_VIDEO_MODE_BLUERAY_6M = 6;      /*! 蓝光 6M */
		public static final int THUNDERPUBLISH_VIDEO_MODE_BLUERAY_8M = 7;      /*! 蓝光 8M */
	}
}

==> yylivesdk4cloud-audiovideo-2.2.14-sources.jar: com/yy/yylivesdk4cloud/ThunderConstant.java <==
package com.yy.yylivesdk4cloud;

/**
 * Created by xiongxiong on 2017/10/30.
 */

/**
 * 业务接入时请使用ThunderRtcConstant中相应的枚举，该类已被废弃
 *
 * @deprecated Deprecated since 2.2.1.
 *
 * @since 2.2.1
 */
@Deprecated
public final class ThunderConstant {

	public static final class ThunderAreaType {
		/**
		 * 默认值(国内)
		 */
		public static final int THUNDERAREA_DEFAULT = 0;
		/**
		 * 俄罗斯
		 */
		public static final int THUNDERAREA_RUSSIA = 1;
		/**
		 * 马来西亚
		 */
		public static final int THUNDERAREA_MALAYSIA = 2;
		/**
		 * 国外
		 */
		public static final int THUNDERAREA_FOREIGN = 100;
		/**
		 * yy-reserved
		 */
		public static final int THUNDERAREA_RESERVED = 101;
	}

	public static final class ThunderUserRole {
		/**
		 * 纯观众
		 */
		public static final int THUNDERUSER_ROLE_AUDIENCE = 0;
		/**
		 * 主播，如果观众跟主播连麦后则自己也成为了主播
		 */
		public static final int THUNDERUSER_ROLE_ANCHOR = 1;
	}

	public static final class ThunderLogLevel {
		public static final int THUNDERLOG_LEVEL_TRACE = 0;
		public static final int THUNDERLOG_LEVEL_DEBUG = 1;
		public static final int THUNDERLOG_LEVEL_INFO = 2;
		public static final int THUNDERLOG_LEVEL_WARN = 3;
		public static final int THUNDERLOG_LEVEL_ERROR = 4;
		public static final int THUNDERLOG_LEVEL_RELEASE = 10;
	}

	public static final class ThunderCameraPosition {
		public static final int THUNDERCAMERA_POSITION_FRONT = 0;
		public static final int THUNDERCAMERA_POSITION_BACK = 1;
	}

	public static final class ThunderPublishOrientation {
		public static final int THUNDERPUBLISH_VIDEO_ORIENTATION_PORTRAIT = 0;
		public static final int THUNDERPUBLISH_VIDEO_ORIENTATION_LANDSCAPE = 1;
	}

	public static final class ThunderVideoEncodeType {
		public static final int THUNDERVIDEO_ENCODE_TYPE_H264 = 1;
		public static final int THUNDERVIDEO_ENCODE_TYPE_H265 = 2;
	}

	public static final class ThunderVideoViewScaleMode {
		public static final int THUNDERVIDEOVIEW_SCALE_MODE_FILL = 0;
		public static final int THUNDERVIDEOVIEW_SCALE_MODE_ASPECT_FIT = 1;
		public static final int THUNDERVIDEOVIEW_SCALE_MODE_CLIP_TO_BOUNDS = 2;
	}

	/*! 使用 YYVideoLevel代替*/
	@Deprecated
	public static final class ThunderStreamLevelType {
		public static final int THUNDERSTREAM_LEVEL_360P = 1;
		public static final int THUNDERSTREAM_LEVEL_540P = 2;
		public static final int THUNDERSTREAM_LEVEL_720P = 3;
		public static final int THUNDERSTREAM_LEVEL_720P60S = 4;
		public static final int THUNDERSTREAM_LEVEL_1080P = 5;
	}

	public static final class ThunderSoundEffectMode {
		public static final int THUNDERSOUND_EFFECT_MODE_NONE = 0; //关闭模式
		public static final int THUNDERSOUND_EFFECT_MODE_VALLEY = 1; //VALLEY模式
		public static final int THUNDERSOUND_EFFECT_MODE_RANDB = 2; //R&B模式
		public static final int THUNDERSOUND_EFFECT_MODE_KTV = 3; //KTV模式
		public static final int THUNDERSOUND_EFFECT_MODE_CHARMING = 4; // CHARMING模式
	}

	/**
	 * 目前观众网使用的流通知中流对应的档位
	 */
	public static final class ThunderVideoLevel {
		public static final int THUNDERVIDEO_LEVEL_NORMAL = 1; /*! 普通 */
		public static final int THUNDERVIDEO_LEVEL_HIGHQULITY = 2; /*! 高清 */
		public static final int THUNDERVIDEO_LEVEL_SUPERQULITY = 3; /*! 超清 */
		public static final int THUNDERVIDEO_LEVEL_BLUERAY_2M = 4; /*! 蓝光 2M */
		public static final int THUNDERVIDEO_LEVEL_BLUERAY_4M = 5; /*! 蓝光 4M */
		public static final int THUNDERVIDEO_LEVEL_BLUERAY_6M = 6; /*! 蓝光 6M */
		public static final int THUNDERVIDEO_LEVEL_BLUERAY_8M = 7; /*! 蓝光 8M */
	}

	public static final class ThunderPublishPlayType {
		public static final int THUNDERPUBLISH_PLAY_SINGLE = 0;  // 单人开播
		public static final int THUNDERPUBLISH_PLAY_INTERACT = 1;  // 视频连麦开播
		public static final int THUNDERPUBLISH_PLAY_SCREENCAP = 2;  // 录屏开播
	}

	/**
	 * 开播档位
	 */
	public static final class ThunderPublishVideoMode {
		public static final int THUNDERPUBLISH_VIDEO_MODE_DEFAULT = -1;        /*! 未定义，由配置自由决定开播清晰度*/
		public static final int THUNDERPUBLISH_VIDEO_MODE_NORMAL = 1;          /*! 普通 */
		public static final int THUNDERPUBLISH_VIDEO_MODE_HIGHQULITY = 2;      /*! 高清 */
		public static final int THUNDERPUBLISH_VIDEO_MODE_SUPERQULITY = 3;     /*! 超清 */
		public static final int THUNDERPUBLISH_VIDEO_MODE_BLUERAY_2M = 4;      /*! 蓝光 2M */
		public static final int THUNDERPUBLISH_VIDEO_MODE_BLUERAY_4M = 5;      /*! 蓝光 4M */
		public static final int THUNDERPUBLISH_VIDEO_MODE_BLUERAY_6M = 6;      /*! 蓝光 6M */
		public static final int THUNDERPUBLISH_VIDEO_MODE_BLUERAY_8M = 7;      /*! 蓝光 8M */
		public static final int THUNDERPUBLISH_VIDEO_MODE_FLUENCY = 8;		  /*! 流畅 200k码率仅供vipkid使用 */
	}

	public static final class ThunderVideoViewType {
		public static final int THUNDERVIDEO_VIEW_PREVIEW = 1;	/* 预览View */
		public static final int THUNDERVIDEO_VIEW_PLAYVIEW = 2; /* 播放View */
	}

	public static final class ThunderVideoRenderMode {
		public static final int THUNDER_RENDER_MODE_FILL = 0;
		public static final int THUNDER_RENDER_MODE_ASPECT_FIT = 1;
		public static final int THUNDER_RENDER_MODE_CLIP_TO_BOUNDS = 2;
	}

	public static final class ThunderRtcProfile {
		public static final int THUNDER_PROFILE_DEFAULT = 0;
		public static final int THUNDER_PROFILE_NORMAL = 1;
		public static final int THUNDER_PROFILE_ONLY_AUDIO = 2;
	}
}
